@@ -6,6 +6,7 @@ from .app import Starlite
 from .config import (
     CacheConfig,
     CORSConfig,
+    GZIPConfig,
     OpenAPIConfig,
     StaticFilesConfig,
     TemplateConfig,
@@ -67,9 +68,10 @@ __all__ = [
     "CORSConfig",
     "CacheConfig",
     "Controller",
-    "Dependency",
     "DTOFactory",
+    "Dependency",
     "File",
+    "GZIPConfig",
     "HTTPException",
     "HTTPRoute",
     "HTTPRouteHandler",
