@@ -6,6 +6,7 @@ from pydantic import validate_arguments
 from pydantic.typing import AnyCallable
 from starlette.middleware import Middleware as StarletteMiddleware
 from starlette.middleware.cors import CORSMiddleware
+from starlette.middleware.gzip import GZipMiddleware
 from starlette.middleware.trustedhost import TrustedHostMiddleware
 from starlette.staticfiles import StaticFiles
 from starlette.types import ASGIApp, Receive, Scope, Send
@@ -15,11 +16,13 @@ from starlite.asgi import StarliteASGIRouter
 from starlite.config import (
     CacheConfig,
     CORSConfig,
+    GZIPConfig,
     OpenAPIConfig,
     StaticFilesConfig,
     TemplateConfig,
 )
 from starlite.datastructures import State
+from starlite.exceptions import ImproperlyConfiguredException
 from starlite.handlers.asgi import ASGIRouteHandler, asgi
 from starlite.handlers.base import BaseRouteHandler
 from starlite.handlers.http import HTTPRouteHandler
@@ -31,7 +34,7 @@ from starlite.provide import Provide
 from starlite.response import Response
 from starlite.router import Router
 from starlite.routes import ASGIRoute, BaseRoute, HTTPRoute, WebSocketRoute
-from starlite.signature import model_function_signature
+from starlite.signature import SignatureModelFactory
 from starlite.types import (
     AfterRequestHandler,
     BeforeRequestHandler,
@@ -51,21 +54,20 @@ DEFAULT_CACHE_CONFIG = CacheConfig()
 
 class Starlite(Router):
     __slots__ = (
+        "allowed_hosts",
         "asgi_handler",
         "asgi_router",
-        "debug",
-        "openapi_schema",
-        "plugins",
-        "state",
-        "route_map",
-        "static_paths",
-        "plain_routes",
-        "template_engine",
         "cache_config",
         "cors_config",
-        "allowed_hosts",
-        # the rest of __slots__ are defined in Router and should not be duplicated
-        # see: https://stackoverflow.com/questions/472000/usage-of-slots
+        "debug",
+        "gzip_config",
+        "openapi_schema",
+        "plain_routes",
+        "plugins",
+        "route_map",
+        "state",
+        "static_paths",
+        "template_engine",
     )
 
     @validate_arguments(config={"arbitrary_types_allowed": True})
@@ -81,6 +83,7 @@ class Starlite(Router):
         dependencies: Optional[Dict[str, Provide]] = None,
         exception_handlers: Optional[Dict[Union[int, Type[Exception]], ExceptionHandler]] = None,
         guards: Optional[List[Guard]] = None,
+        gzip_config: Optional[GZIPConfig] = None,
         middleware: Optional[List[Middleware]] = None,
         on_shutdown: Optional[List[LifeCycleHandler]] = None,
         on_startup: Optional[List[LifeCycleHandler]] = None,
@@ -92,16 +95,17 @@ class Starlite(Router):
         static_files_config: Optional[Union[StaticFilesConfig, List[StaticFilesConfig]]] = None,
         template_config: Optional[TemplateConfig] = None,
     ):
-        self.debug = debug
-        self.state = State()
-        self.plugins = plugins or []
-        self.routes: List[BaseRoute] = []
-        self.route_map: Dict[str, Any] = {}
-        self.static_paths = set()
-        self.plain_routes: Set[str] = set()
+        self.allowed_hosts = allowed_hosts
         self.cache_config = cache_config
         self.cors_config = cors_config
-        self.allowed_hosts = allowed_hosts
+        self.debug = debug
+        self.gzip_config = gzip_config
+        self.plain_routes: Set[str] = set()
+        self.plugins = plugins or []
+        self.route_map: Dict[str, Any] = {}
+        self.routes: List[BaseRoute] = []
+        self.state = State()
+        self.static_paths = set()
 
         super().__init__(
             dependencies=dependencies,
@@ -138,6 +142,8 @@ class Starlite(Router):
         If CORS or TruseedHost configs are provided to the constructor, they will wrap the router as well.
         """
         asgi_handler: ASGIApp = self.asgi_router
+        if self.gzip_config:
+            asgi_handler = GZipMiddleware(app=asgi_handler, **self.gzip_config.dict())
         if self.allowed_hosts:
             asgi_handler = TrustedHostMiddleware(app=asgi_handler, allowed_hosts=self.allowed_hosts)
         if self.cors_config:
@@ -168,11 +174,12 @@ class Starlite(Router):
 
         return ExceptionHandlerMiddleware(app=app, exception_handlers=exception_handlers, debug=self.debug)
 
-    def construct_route_map(self) -> None:  # noqa: C901
+    def construct_route_map(self) -> None:  # noqa: C901 # pylint: disable=R0912
         """
         Create a map of the app's routes. This map is used in the asgi router to route requests.
 
         """
+        seen_param_paths = set()
         if "_components" not in self.route_map:
             self.route_map["_components"] = set()
         for route in self.routes:
@@ -181,6 +188,9 @@ class Starlite(Router):
                 for param_definition in route.path_parameters:
                     path = path.replace(param_definition["full"], "")
                 path = path.replace("{}", "*")
+                if path in seen_param_paths:
+                    raise ImproperlyConfiguredException("Should not use routes with conflicting path parameters")
+                seen_param_paths.add(path)
                 cur = self.route_map
                 components = ["/", *[component for component in path.split("/") if component]]
                 for component in components:
@@ -190,7 +200,8 @@ class Starlite(Router):
                         cur[component] = {"_components": set()}
                     cur = cast(Dict[str, Any], cur[component])
             else:
-                self.route_map[path] = {"_components": set()}
+                if path not in self.route_map:
+                    self.route_map[path] = {"_components": set()}
                 self.plain_routes.add(path)
                 cur = self.route_map[path]
             if "_path_parameters" not in cur:
@@ -267,18 +278,18 @@ class Starlite(Router):
         Creates function signature models for all route handler functions and provider dependencies
         """
         if not route_handler.signature_model:
-            route_handler.signature_model = model_function_signature(
+            route_handler.signature_model = SignatureModelFactory(
                 fn=cast(AnyCallable, route_handler.fn),
                 plugins=self.plugins,
                 provided_dependency_names=route_handler.dependency_name_set,
-            )
+            ).model()
         for provider in list(route_handler.resolve_dependencies().values()):
             if not provider.signature_model:
-                provider.signature_model = model_function_signature(
+                provider.signature_model = SignatureModelFactory(
                     fn=provider.dependency,
                     plugins=self.plugins,
                     provided_dependency_names=route_handler.dependency_name_set,
-                )
+                ).model()
 
     def create_openapi_schema_model(self, openapi_config: OpenAPIConfig) -> OpenAPI:
         """
