@@ -14,7 +14,10 @@ except ImportError as exc:  # pragma: no cover
 
 
 class JinjaTemplateEngine(TemplateEngineProtocol[JinjaTemplate]):
+    """Template engine using the jinja templating library"""
+
     def __init__(self, directory: Union[DirectoryPath, List[DirectoryPath]]) -> None:
+        super().__init__(directory)
         loader = FileSystemLoader(searchpath=directory)
         self.engine = Environment(loader=loader, autoescape=True)
 
