@@ -11,6 +11,7 @@ from starlite.app import DEFAULT_CACHE_CONFIG, Starlite
 from starlite.config import (
     CacheConfig,
     CORSConfig,
+    GZIPConfig,
     OpenAPIConfig,
     StaticFilesConfig,
     TemplateConfig,
@@ -110,26 +111,28 @@ def create_test_client(
         Union[Type[Controller], BaseRouteHandler, Router, AnyCallable],
         List[Union[Type[Controller], BaseRouteHandler, Router, AnyCallable]],
     ],
+    *,
     after_request: Optional[AfterRequestHandler] = None,
     allowed_hosts: Optional[List[str]] = None,
     backend: str = "asyncio",
     backend_options: Optional[Dict[str, Any]] = None,
     base_url: str = "http://testserver",
     before_request: Optional[BeforeRequestHandler] = None,
+    cache_config: CacheConfig = DEFAULT_CACHE_CONFIG,
     cors_config: Optional[CORSConfig] = None,
     dependencies: Optional[Dict[str, Provide]] = None,
     exception_handlers: Optional[Dict[Union[int, Type[Exception]], ExceptionHandler]] = None,
     guards: Optional[List[Guard]] = None,
+    gzip_config: Optional[GZIPConfig] = None,
     middleware: Optional[List[Middleware]] = None,
     on_shutdown: Optional[List[LifeCycleHandler]] = None,
     on_startup: Optional[List[LifeCycleHandler]] = None,
     openapi_config: Optional[OpenAPIConfig] = None,
-    template_config: Optional[TemplateConfig] = None,
     plugins: Optional[List[PluginProtocol]] = None,
     raise_server_exceptions: bool = True,
     root_path: str = "",
     static_files_config: Optional[Union[StaticFilesConfig, List[StaticFilesConfig]]] = None,
-    cache_config: CacheConfig = DEFAULT_CACHE_CONFIG,
+    template_config: Optional[TemplateConfig] = None,
 ) -> TestClient:
     """Create a TestClient"""
     return TestClient(
@@ -137,19 +140,20 @@ def create_test_client(
             after_request=after_request,
             allowed_hosts=allowed_hosts,
             before_request=before_request,
+            cache_config=cache_config,
             cors_config=cors_config,
             dependencies=dependencies,
             exception_handlers=exception_handlers,
             guards=guards,
+            gzip_config=gzip_config,
             middleware=middleware,
             on_shutdown=on_shutdown,
             on_startup=on_startup,
             openapi_config=openapi_config,
-            template_config=template_config,
             plugins=plugins,
             route_handlers=cast(Any, route_handlers if isinstance(route_handlers, list) else [route_handlers]),
             static_files_config=static_files_config,
-            cache_config=cache_config,
+            template_config=template_config,
         ),
         backend=backend,
         backend_options=backend_options,
